﻿using Infragistics.Controls.Layouts;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Media;

namespace XamTileManagerSelection
{
    public class CustomTileManager : XamTileManager
    {

        public CustomTileManager()
        {
            this.Loaded += CustomTileManager_Loaded;
        }

        static SolidColorBrush NotSelectedBrush = new SolidColorBrush(Colors.White);
        static SolidColorBrush SelectedBrush = new SolidColorBrush(Colors.Red);

        #region LoadedEvent
        void CustomTileManager_Loaded(object sender, RoutedEventArgs e)
        {
            XamTileManager xtm = sender as XamTileManager;

            Dispatcher.BeginInvoke(new Action(() =>
            {

                foreach (var x in xtm.Items)
                {
                    if (x is SampleData)
                    {
                        SampleData sd = x as SampleData;
                        XamTile tile = xtm.TileFromItem(sd);

                        if (tile != null)
                        {                            
                            if (this.SelectedItem == sd)
                            {
                                tile.Background = SelectedBrush;
                            }
                            else
                            {
                                tile.Background = NotSelectedBrush;
                            }
                        }
                    }
                }
            }));
        }
        #endregion        

        #region SelectedItemProperty
        public object SelectedItem
        {
            get { return (object)GetValue(SelectedItemProperty); }
            set { SetValue(SelectedItemProperty, value); }
        }

        // Using a DependencyProperty as the backing store for SelectedItem.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty SelectedItemProperty =
            DependencyProperty.Register("SelectedItem", typeof(object), typeof(CustomTileManager), new PropertyMetadata(null, new PropertyChangedCallback(SelectedItemChanged)));

       
        static void SelectedItemChanged(DependencyObject o, DependencyPropertyChangedEventArgs e)
        {

            CustomTileManager ctm = o as CustomTileManager;

            if (e.OldValue != null)
            {
                SampleData SD = e.OldValue as SampleData;
                XamTile tile = ctm.TileFromItem(SD);

                if (tile != null)
                {
                    tile.Background = NotSelectedBrush;
                }
            }

            if (e.NewValue != null)
            {
                SampleData newSD = e.NewValue as SampleData;

                XamTile newTile = ctm.TileFromItem(newSD);

                if (newTile != null)
                {
                    newTile.Background = SelectedBrush;
                }
            }
        }
        #endregion
    }
}
